==> g3data_1.4.0.1.orig.tar.gz: g3data-1.4.0.1/tooltips.h <==
gchar setx1tts[] =	"Put out first point on x axis";
gchar setx1tt[] =	"To set out first point on x axis press this button and then press on the "
			"image x-axis (with left mousebutton). This procedure can be replaced by "
			"pressing the middle button on the image.";

gchar setx2tts[] =	"Put out second point on x axis";
gchar setx2tt[] =	"To set out second point on x axis press this button and then press on the "
			"image x-axis (with left mousebutton). This procedure can be replaced by "
			"pressing the middle button on the image.";

gchar sety1tts[] =	"Put out first point on y axis";
gchar sety1tt[] =	"To set out first point on y axis press this button and then press on the "
			"image y-axis (with left mousebutton). This procedure can be replaced by "
			"pressing the right button on the image.";

gchar sety2tts[] =	"Put out second point on y axis";
gchar sety2tt[] =	"To set out second point on y axis press this button and then press on the "
			"image y-axis (with left mousebutton). This procedure can be replaced by "
			"pressing the right button on the image.";

gchar *setxytts[] = {&setx1tts[0], &setx2tts[0], &sety1tts[0], &sety2tts[0]};
gchar *setxytt[] = {&setx1tt[0], &setx2tt[0], &sety1tt[0], &sety2tt[0]};

gchar entryx1tt[] =	"This entry should contain the value of the first x-axis point.";

gchar entryx2tt[] =	"This entry should contain the value of the second x-axis point.";

gchar entryy1tt[] =	"This entry should contain the value of the first y-axis point.";

gchar entryy2tt[] =	"This entry should contain the value of the second y-axis point.";

gchar *entryxytt[] = {&entryx1tt[0], &entryx2tt[0], &entryy1tt[0], &entryy2tt[0]};

gchar removeltt[] =	"This button removes the last put out point.";

gchar removeatts[] =	"Remove all points";
gchar removeatt[] =	"This button removes all put out points except the axispoints. If all "
			"points are already removed a second click will also remove the axispoints.";

gchar printrestt[] =	"Print data to stdout.";

gchar printfilett[] =	"Print data to file with name defined in entrybox.";

gchar filenamett[] =	"This entry should contain the name of the file to print data to.";

gchar logxtt[] =	"If x-axis is logarithmic check this button.";

gchar logytt[] =	"If y-axis is logarithmic check this button.";

gchar uetts[] = 	"Show the errors of the x and y values at printout.";

gchar uett[] =		"If you want the errors of the x value to be printed in column 3 and the error "
			"of the y value to be printed in column 4 check this button.";

==> g3data_1.08.orig.tar.gz: g3data-1.0.8/tooltips.h <==
gchar setx1tt[] =	"To set out first point on x axis press this button and then press on the "
			"image x-axis. This procedure can be replaced by pressing the middle button "
			"on the image.";

gchar setx2tt[] =	"To set out second point on x axis press this button and then press on the "
			"image x-axis. This procedure can be replaced by pressing the middle button "
			"on the image.";

gchar sety1tt[] =	"To set out first point on y axis press this button and then press on the "
			"image y-axis. This procedure can be replaced by pressing the right button "
			"on the image.";

gchar sety2tt[] =	"To set out second point on y axis press this button and then press on the "
			"image y-axis. This procedure can be replaced by pressing the right button "
			"on the image.";

gchar entryx1tt[] =	"This entry should contain the value of the first x-axis point.";

gchar entryx2tt[] =	"This entry should contain the value of the second x-axis point.";

gchar entryy1tt[] =	"This entry should contain the value of the first y-axis point.";

gchar entryy2tt[] =	"This entry should contain the value of the second y-axis point.";

gchar removeltt[] =	"This button removes the last put out point.";

gchar removeatt[] =	"This button removes all put out points except the axispoints. If all "
			"points are already removed a second click will also remove the axispoints.";

gchar printrestt[] =	"Print data to stdout.";

gchar printfilett[] =	"Print data to file with name defined in entrybox.";

gchar filenamett[] =	"This entry should contain the name of the file to print data to.";

gchar logxtt[] =	"If x-axis is logarithmic check this button.";

gchar logytt[] =	"If y-axis is logarithmic check this button.";
